@@ -17,17 +17,23 @@
 from .services.assured_workloads_service import AssuredWorkloadsServiceClient
 from .services.assured_workloads_service import AssuredWorkloadsServiceAsyncClient
 
-from .types.assuredworkloads_v1beta1 import CreateWorkloadOperationMetadata
-from .types.assuredworkloads_v1beta1 import CreateWorkloadRequest
-from .types.assuredworkloads_v1beta1 import DeleteWorkloadRequest
-from .types.assuredworkloads_v1beta1 import GetWorkloadRequest
-from .types.assuredworkloads_v1beta1 import ListWorkloadsRequest
-from .types.assuredworkloads_v1beta1 import ListWorkloadsResponse
-from .types.assuredworkloads_v1beta1 import UpdateWorkloadRequest
-from .types.assuredworkloads_v1beta1 import Workload
+from .types.assuredworkloads import AnalyzeWorkloadMoveRequest
+from .types.assuredworkloads import AnalyzeWorkloadMoveResponse
+from .types.assuredworkloads import CreateWorkloadOperationMetadata
+from .types.assuredworkloads import CreateWorkloadRequest
+from .types.assuredworkloads import DeleteWorkloadRequest
+from .types.assuredworkloads import GetWorkloadRequest
+from .types.assuredworkloads import ListWorkloadsRequest
+from .types.assuredworkloads import ListWorkloadsResponse
+from .types.assuredworkloads import RestrictAllowedResourcesRequest
+from .types.assuredworkloads import RestrictAllowedResourcesResponse
+from .types.assuredworkloads import UpdateWorkloadRequest
+from .types.assuredworkloads import Workload
 
 __all__ = (
     "AssuredWorkloadsServiceAsyncClient",
+    "AnalyzeWorkloadMoveRequest",
+    "AnalyzeWorkloadMoveResponse",
     "AssuredWorkloadsServiceClient",
     "CreateWorkloadOperationMetadata",
     "CreateWorkloadRequest",
@@ -35,6 +41,8 @@ __all__ = (
     "GetWorkloadRequest",
     "ListWorkloadsRequest",
     "ListWorkloadsResponse",
+    "RestrictAllowedResourcesRequest",
+    "RestrictAllowedResourcesResponse",
     "UpdateWorkloadRequest",
     "Workload",
 )
