@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -36,7 +36,8 @@ from google.api_core import operation_async  # type: ignore
 from google.cloud.assuredworkloads_v1beta1.services.assured_workloads_service import (
     pagers,
 )
-from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads_v1beta1
+from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads
+from google.longrunning import operations_pb2
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import AssuredWorkloadsServiceTransport, DEFAULT_CLIENT_INFO
@@ -217,10 +218,10 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def create_workload(
         self,
-        request: Union[assuredworkloads_v1beta1.CreateWorkloadRequest, dict] = None,
+        request: Union[assuredworkloads.CreateWorkloadRequest, dict] = None,
         *,
         parent: str = None,
-        workload: assuredworkloads_v1beta1.Workload = None,
+        workload: assuredworkloads.Workload = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -231,14 +232,14 @@ class AssuredWorkloadsServiceAsyncClient:
 
             from google.cloud import assuredworkloads_v1beta1
 
-            def sample_create_workload():
+            async def sample_create_workload():
                 # Create a client
-                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceClient()
+                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 workload = assuredworkloads_v1beta1.Workload()
                 workload.display_name = "display_name_value"
-                workload.compliance_regime = "CA_REGIONS_AND_SUPPORT"
+                workload.compliance_regime = "AU_REGIONS_AND_US_SUPPORT"
 
                 request = assuredworkloads_v1beta1.CreateWorkloadRequest(
                     parent="parent_value",
@@ -250,7 +251,7 @@ class AssuredWorkloadsServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -295,7 +296,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 "the individual field arguments should be set."
             )
 
-        request = assuredworkloads_v1beta1.CreateWorkloadRequest(request)
+        request = assuredworkloads.CreateWorkloadRequest(request)
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
@@ -319,14 +320,19 @@ class AssuredWorkloadsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
             response,
             self._client._transport.operations_client,
-            assuredworkloads_v1beta1.Workload,
-            metadata_type=assuredworkloads_v1beta1.CreateWorkloadOperationMetadata,
+            assuredworkloads.Workload,
+            metadata_type=assuredworkloads.CreateWorkloadOperationMetadata,
         )
 
         # Done; return the response.
@@ -334,39 +340,38 @@ class AssuredWorkloadsServiceAsyncClient:
 
     async def update_workload(
         self,
-        request: Union[assuredworkloads_v1beta1.UpdateWorkloadRequest, dict] = None,
+        request: Union[assuredworkloads.UpdateWorkloadRequest, dict] = None,
         *,
-        workload: assuredworkloads_v1beta1.Workload = None,
+        workload: assuredworkloads.Workload = None,
         update_mask: field_mask_pb2.FieldMask = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> assuredworkloads_v1beta1.Workload:
+    ) -> assuredworkloads.Workload:
         r"""Updates an existing workload. Currently allows updating of
         workload display_name and labels. For force updates don't set
         etag field in the Workload. Only one update operation per
         workload can be in progress.
 
-
         .. code-block:: python
 
             from google.cloud import assuredworkloads_v1beta1
 
-            def sample_update_workload():
+            async def sample_update_workload():
                 # Create a client
-                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceClient()
+                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 workload = assuredworkloads_v1beta1.Workload()
                 workload.display_name = "display_name_value"
-                workload.compliance_regime = "CA_REGIONS_AND_SUPPORT"
+                workload.compliance_regime = "AU_REGIONS_AND_US_SUPPORT"
 
                 request = assuredworkloads_v1beta1.UpdateWorkloadRequest(
                     workload=workload,
                 )
 
                 # Make the request
-                response = client.update_workload(request=request)
+                response = await client.update_workload(request=request)
 
                 # Handle the response
                 print(response)
@@ -375,7 +380,7 @@ class AssuredWorkloadsServiceAsyncClient:
             request (Union[google.cloud.assuredworkloads_v1beta1.types.UpdateWorkloadRequest, dict]):
                 The request object. Request for Updating a workload.
             workload (:class:`google.cloud.assuredworkloads_v1beta1.types.Workload`):
-                Required. The workload to update. The workload’s
+                Required. The workload to update. The workload's
                 ``name`` field is used to identify the workload to be
                 updated. Format:
                 organizations/{org_id}/locations/{location_id}/workloads/{workload_id}
@@ -413,7 +418,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 "the individual field arguments should be set."
             )
 
-        request = assuredworkloads_v1beta1.UpdateWorkloadRequest(request)
+        request = assuredworkloads.UpdateWorkloadRequest(request)
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
@@ -430,23 +435,101 @@ class AssuredWorkloadsServiceAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def restrict_allowed_resources(
+        self,
+        request: Union[assuredworkloads.RestrictAllowedResourcesRequest, dict] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> assuredworkloads.RestrictAllowedResourcesResponse:
+        r"""Restrict the list of resources allowed in the
+        Workload environment. The current list of allowed
+        products can be found at
+        https://cloud.google.com/assured-workloads/docs/supported-products
+        In addition to assuredworkloads.workload.update
+        permission, the user should also have
+        orgpolicy.policy.set permission on the folder resource
+        to use this functionality.
+
+        .. code-block:: python
+
+            from google.cloud import assuredworkloads_v1beta1
+
+            async def sample_restrict_allowed_resources():
+                # Create a client
+                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = assuredworkloads_v1beta1.RestrictAllowedResourcesRequest(
+                    name="name_value",
+                    restriction_type="ALLOW_COMPLIANT_RESOURCES",
+                )
+
+                # Make the request
+                response = await client.restrict_allowed_resources(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.assuredworkloads_v1beta1.types.RestrictAllowedResourcesRequest, dict]):
+                The request object. Request for restricting list of
+                available resources in Workload environment.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.assuredworkloads_v1beta1.types.RestrictAllowedResourcesResponse:
+                Response for restricting the list of
+                allowed resources.
+
+        """
+        # Create or coerce a protobuf request object.
+        request = assuredworkloads.RestrictAllowedResourcesRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.restrict_allowed_resources,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
         # Certain fields should be provided within the metadata header;
         # add these here.
         metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata(
-                (("workload.name", request.workload.name),)
-            ),
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def delete_workload(
         self,
-        request: Union[assuredworkloads_v1beta1.DeleteWorkloadRequest, dict] = None,
+        request: Union[assuredworkloads.DeleteWorkloadRequest, dict] = None,
         *,
         name: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
@@ -455,16 +538,18 @@ class AssuredWorkloadsServiceAsyncClient:
     ) -> None:
         r"""Deletes the workload. Make sure that workload's direct children
         are already in a deleted state, otherwise the request will fail
-        with a FAILED_PRECONDITION error.
-
+        with a FAILED_PRECONDITION error. In addition to
+        assuredworkloads.workload.delete permission, the user should
+        also have orgpolicy.policy.set permission on the deleted folder
+        to remove Assured Workloads OrgPolicies.
 
         .. code-block:: python
 
             from google.cloud import assuredworkloads_v1beta1
 
-            def sample_delete_workload():
+            async def sample_delete_workload():
                 # Create a client
-                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceClient()
+                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = assuredworkloads_v1beta1.DeleteWorkloadRequest(
@@ -472,7 +557,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 )
 
                 # Make the request
-                client.delete_workload(request=request)
+                await client.delete_workload(request=request)
 
         Args:
             request (Union[google.cloud.assuredworkloads_v1beta1.types.DeleteWorkloadRequest, dict]):
@@ -501,7 +586,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 "the individual field arguments should be set."
             )
 
-        request = assuredworkloads_v1beta1.DeleteWorkloadRequest(request)
+        request = assuredworkloads.DeleteWorkloadRequest(request)
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
@@ -533,27 +618,30 @@ class AssuredWorkloadsServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def get_workload(
         self,
-        request: Union[assuredworkloads_v1beta1.GetWorkloadRequest, dict] = None,
+        request: Union[assuredworkloads.GetWorkloadRequest, dict] = None,
         *,
         name: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> assuredworkloads_v1beta1.Workload:
+    ) -> assuredworkloads.Workload:
         r"""Gets Assured Workload associated with a CRM Node
 
         .. code-block:: python
 
             from google.cloud import assuredworkloads_v1beta1
 
-            def sample_get_workload():
+            async def sample_get_workload():
                 # Create a client
-                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceClient()
+                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = assuredworkloads_v1beta1.GetWorkloadRequest(
@@ -561,7 +649,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_workload(request=request)
+                response = await client.get_workload(request=request)
 
                 # Handle the response
                 print(response)
@@ -603,7 +691,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 "the individual field arguments should be set."
             )
 
-        request = assuredworkloads_v1beta1.GetWorkloadRequest(request)
+        request = assuredworkloads.GetWorkloadRequest(request)
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
@@ -627,21 +715,141 @@ class AssuredWorkloadsServiceAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
-        # Certain fields should be provided within the metadata header;
-        # add these here.
-        metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def analyze_workload_move(
+        self,
+        request: Union[assuredworkloads.AnalyzeWorkloadMoveRequest, dict] = None,
+        *,
+        project: str = None,
+        target: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> assuredworkloads.AnalyzeWorkloadMoveResponse:
+        r"""Analyze if the source Assured Workloads can be moved
+        to the target Assured Workload
+
+        .. code-block:: python
+
+            from google.cloud import assuredworkloads_v1beta1
+
+            async def sample_analyze_workload_move():
+                # Create a client
+                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = assuredworkloads_v1beta1.AnalyzeWorkloadMoveRequest(
+                    source="source_value",
+                    target="target_value",
+                )
+
+                # Make the request
+                response = await client.analyze_workload_move(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.assuredworkloads_v1beta1.types.AnalyzeWorkloadMoveRequest, dict]):
+                The request object. A request to analyze a hypothetical
+                move of a source project or project-based workload to a
+                target (destination) folder-based workload.
+            project (:class:`str`):
+                The source type is a project. Specify the project's
+                relative resource name, formatted as either a project
+                number or a project ID: "projects/{PROJECT_NUMBER}" or
+                "projects/{PROJECT_ID}" For example:
+                "projects/951040570662" when specifying a project
+                number, or "projects/my-project-123" when specifying a
+                project ID.
+
+                This corresponds to the ``project`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            target (:class:`str`):
+                Required. The resource ID of the folder-based
+                destination workload. This workload is where the source
+                project will hypothetically be moved to. Specify the
+                workload's relative resource name, formatted as:
+                "organizations/{ORGANIZATION_ID}/locations/{LOCATION_ID}/workloads/{WORKLOAD_ID}"
+                For example:
+                "organizations/123/locations/us-east1/workloads/assured-workload-2"
+
+                This corresponds to the ``target`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.assuredworkloads_v1beta1.types.AnalyzeWorkloadMoveResponse:
+                A response that includes the analysis
+                of the hypothetical resource move.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([project, target])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = assuredworkloads.AnalyzeWorkloadMoveRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if project is not None:
+            request.project = project
+        if target is not None:
+            request.target = target
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.analyze_workload_move,
+            default_retry=retries.Retry(
+                initial=0.2,
+                maximum=30.0,
+                multiplier=1.3,
+                predicate=retries.if_exception_type(
+                    core_exceptions.ServiceUnavailable,
+                ),
+                deadline=60.0,
+            ),
+            default_timeout=60.0,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def list_workloads(
         self,
-        request: Union[assuredworkloads_v1beta1.ListWorkloadsRequest, dict] = None,
+        request: Union[assuredworkloads.ListWorkloadsRequest, dict] = None,
         *,
         parent: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
@@ -654,9 +862,9 @@ class AssuredWorkloadsServiceAsyncClient:
 
             from google.cloud import assuredworkloads_v1beta1
 
-            def sample_list_workloads():
+            async def sample_list_workloads():
                 # Create a client
-                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceClient()
+                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = assuredworkloads_v1beta1.ListWorkloadsRequest(
@@ -667,7 +875,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 page_result = client.list_workloads(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -706,7 +914,7 @@ class AssuredWorkloadsServiceAsyncClient:
                 "the individual field arguments should be set."
             )
 
-        request = assuredworkloads_v1beta1.ListWorkloadsRequest(request)
+        request = assuredworkloads.ListWorkloadsRequest(request)
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
@@ -730,19 +938,129 @@ class AssuredWorkloadsServiceAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
-        # Certain fields should be provided within the metadata header;
-        # add these here.
-        metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
-        )
-
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListWorkloadsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def list_operations(
+        self,
+        request: operations_pb2.ListOperationsRequest = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operations_pb2.ListOperationsResponse:
+        r"""Lists operations that match the specified filter in the request.
+
+        Args:
+            request (:class:`~.operations_pb2.ListOperationsRequest`):
+                The request object. Request message for
+                `ListOperations` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.operations_pb2.ListOperationsResponse:
+                Response message for ``ListOperations`` method.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.ListOperationsRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._client._transport.list_operations,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def get_operation(
+        self,
+        request: operations_pb2.GetOperationRequest = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operations_pb2.Operation:
+        r"""Gets the latest state of a long-running operation.
+
+        Args:
+            request (:class:`~.operations_pb2.GetOperationRequest`):
+                The request object. Request message for
+                `GetOperation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.operations_pb2.Operation:
+                An ``Operation`` object.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.GetOperationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._client._transport.get_operation,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
         # Done; return the response.
