@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -39,7 +39,8 @@ from google.api_core import operation_async  # type: ignore
 from google.cloud.assuredworkloads_v1beta1.services.assured_workloads_service import (
     pagers,
 )
-from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads_v1beta1
+from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads
+from google.longrunning import operations_pb2
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import AssuredWorkloadsServiceTransport, DEFAULT_CLIENT_INFO
@@ -62,7 +63,8 @@ class AssuredWorkloadsServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = AssuredWorkloadsServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[AssuredWorkloadsServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -168,10 +170,16 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         return self._transport
 
     @staticmethod
-    def workload_path(organization: str, location: str, workload: str,) -> str:
+    def workload_path(
+        organization: str,
+        location: str,
+        workload: str,
+    ) -> str:
         """Returns a fully-qualified workload string."""
         return "organizations/{organization}/locations/{location}/workloads/{workload}".format(
-            organization=organization, location=location, workload=workload,
+            organization=organization,
+            location=location,
+            workload=workload,
         )
 
     @staticmethod
@@ -184,7 +192,9 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -197,9 +207,13 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -208,9 +222,13 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -219,9 +237,13 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -230,10 +252,14 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -405,14 +431,15 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def create_workload(
         self,
-        request: Union[assuredworkloads_v1beta1.CreateWorkloadRequest, dict] = None,
+        request: Union[assuredworkloads.CreateWorkloadRequest, dict] = None,
         *,
         parent: str = None,
-        workload: assuredworkloads_v1beta1.Workload = None,
+        workload: assuredworkloads.Workload = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -430,7 +457,7 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
                 # Initialize request argument(s)
                 workload = assuredworkloads_v1beta1.Workload()
                 workload.display_name = "display_name_value"
-                workload.compliance_regime = "CA_REGIONS_AND_SUPPORT"
+                workload.compliance_regime = "AU_REGIONS_AND_US_SUPPORT"
 
                 request = assuredworkloads_v1beta1.CreateWorkloadRequest(
                     parent="parent_value",
@@ -488,11 +515,11 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
             )
 
         # Minor optimization to avoid making a copy if the user passes
-        # in a assuredworkloads_v1beta1.CreateWorkloadRequest.
+        # in a assuredworkloads.CreateWorkloadRequest.
         # There's no risk of modifying the input as we've already verified
         # there are no flattened fields.
-        if not isinstance(request, assuredworkloads_v1beta1.CreateWorkloadRequest):
-            request = assuredworkloads_v1beta1.CreateWorkloadRequest(request)
+        if not isinstance(request, assuredworkloads.CreateWorkloadRequest):
+            request = assuredworkloads.CreateWorkloadRequest(request)
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
             if parent is not None:
@@ -511,14 +538,19 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            assuredworkloads_v1beta1.Workload,
-            metadata_type=assuredworkloads_v1beta1.CreateWorkloadOperationMetadata,
+            assuredworkloads.Workload,
+            metadata_type=assuredworkloads.CreateWorkloadOperationMetadata,
         )
 
         # Done; return the response.
@@ -526,20 +558,19 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
 
     def update_workload(
         self,
-        request: Union[assuredworkloads_v1beta1.UpdateWorkloadRequest, dict] = None,
+        request: Union[assuredworkloads.UpdateWorkloadRequest, dict] = None,
         *,
-        workload: assuredworkloads_v1beta1.Workload = None,
+        workload: assuredworkloads.Workload = None,
         update_mask: field_mask_pb2.FieldMask = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> assuredworkloads_v1beta1.Workload:
+    ) -> assuredworkloads.Workload:
         r"""Updates an existing workload. Currently allows updating of
         workload display_name and labels. For force updates don't set
         etag field in the Workload. Only one update operation per
         workload can be in progress.
 
-
         .. code-block:: python
 
             from google.cloud import assuredworkloads_v1beta1
@@ -551,7 +582,7 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
                 # Initialize request argument(s)
                 workload = assuredworkloads_v1beta1.Workload()
                 workload.display_name = "display_name_value"
-                workload.compliance_regime = "CA_REGIONS_AND_SUPPORT"
+                workload.compliance_regime = "AU_REGIONS_AND_US_SUPPORT"
 
                 request = assuredworkloads_v1beta1.UpdateWorkloadRequest(
                     workload=workload,
@@ -567,7 +598,7 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
             request (Union[google.cloud.assuredworkloads_v1beta1.types.UpdateWorkloadRequest, dict]):
                 The request object. Request for Updating a workload.
             workload (google.cloud.assuredworkloads_v1beta1.types.Workload):
-                Required. The workload to update. The workload’s
+                Required. The workload to update. The workload's
                 ``name`` field is used to identify the workload to be
                 updated. Format:
                 organizations/{org_id}/locations/{location_id}/workloads/{workload_id}
@@ -606,11 +637,11 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
             )
 
         # Minor optimization to avoid making a copy if the user passes
-        # in a assuredworkloads_v1beta1.UpdateWorkloadRequest.
+        # in a assuredworkloads.UpdateWorkloadRequest.
         # There's no risk of modifying the input as we've already verified
         # there are no flattened fields.
-        if not isinstance(request, assuredworkloads_v1beta1.UpdateWorkloadRequest):
-            request = assuredworkloads_v1beta1.UpdateWorkloadRequest(request)
+        if not isinstance(request, assuredworkloads.UpdateWorkloadRequest):
+            request = assuredworkloads.UpdateWorkloadRequest(request)
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
             if workload is not None:
@@ -622,23 +653,104 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.update_workload]
 
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def restrict_allowed_resources(
+        self,
+        request: Union[assuredworkloads.RestrictAllowedResourcesRequest, dict] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> assuredworkloads.RestrictAllowedResourcesResponse:
+        r"""Restrict the list of resources allowed in the
+        Workload environment. The current list of allowed
+        products can be found at
+        https://cloud.google.com/assured-workloads/docs/supported-products
+        In addition to assuredworkloads.workload.update
+        permission, the user should also have
+        orgpolicy.policy.set permission on the folder resource
+        to use this functionality.
+
+        .. code-block:: python
+
+            from google.cloud import assuredworkloads_v1beta1
+
+            def sample_restrict_allowed_resources():
+                # Create a client
+                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceClient()
+
+                # Initialize request argument(s)
+                request = assuredworkloads_v1beta1.RestrictAllowedResourcesRequest(
+                    name="name_value",
+                    restriction_type="ALLOW_COMPLIANT_RESOURCES",
+                )
+
+                # Make the request
+                response = client.restrict_allowed_resources(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.assuredworkloads_v1beta1.types.RestrictAllowedResourcesRequest, dict]):
+                The request object. Request for restricting list of
+                available resources in Workload environment.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.assuredworkloads_v1beta1.types.RestrictAllowedResourcesResponse:
+                Response for restricting the list of
+                allowed resources.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Minor optimization to avoid making a copy if the user passes
+        # in a assuredworkloads.RestrictAllowedResourcesRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, assuredworkloads.RestrictAllowedResourcesRequest):
+            request = assuredworkloads.RestrictAllowedResourcesRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[
+            self._transport.restrict_allowed_resources
+        ]
+
         # Certain fields should be provided within the metadata header;
         # add these here.
         metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata(
-                (("workload.name", request.workload.name),)
-            ),
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def delete_workload(
         self,
-        request: Union[assuredworkloads_v1beta1.DeleteWorkloadRequest, dict] = None,
+        request: Union[assuredworkloads.DeleteWorkloadRequest, dict] = None,
         *,
         name: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
@@ -647,8 +759,10 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
     ) -> None:
         r"""Deletes the workload. Make sure that workload's direct children
         are already in a deleted state, otherwise the request will fail
-        with a FAILED_PRECONDITION error.
-
+        with a FAILED_PRECONDITION error. In addition to
+        assuredworkloads.workload.delete permission, the user should
+        also have orgpolicy.policy.set permission on the deleted folder
+        to remove Assured Workloads OrgPolicies.
 
         .. code-block:: python
 
@@ -694,11 +808,11 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
             )
 
         # Minor optimization to avoid making a copy if the user passes
-        # in a assuredworkloads_v1beta1.DeleteWorkloadRequest.
+        # in a assuredworkloads.DeleteWorkloadRequest.
         # There's no risk of modifying the input as we've already verified
         # there are no flattened fields.
-        if not isinstance(request, assuredworkloads_v1beta1.DeleteWorkloadRequest):
-            request = assuredworkloads_v1beta1.DeleteWorkloadRequest(request)
+        if not isinstance(request, assuredworkloads.DeleteWorkloadRequest):
+            request = assuredworkloads.DeleteWorkloadRequest(request)
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
             if name is not None:
@@ -716,18 +830,21 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def get_workload(
         self,
-        request: Union[assuredworkloads_v1beta1.GetWorkloadRequest, dict] = None,
+        request: Union[assuredworkloads.GetWorkloadRequest, dict] = None,
         *,
         name: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> assuredworkloads_v1beta1.Workload:
+    ) -> assuredworkloads.Workload:
         r"""Gets Assured Workload associated with a CRM Node
 
         .. code-block:: python
@@ -787,11 +904,11 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
             )
 
         # Minor optimization to avoid making a copy if the user passes
-        # in a assuredworkloads_v1beta1.GetWorkloadRequest.
+        # in a assuredworkloads.GetWorkloadRequest.
         # There's no risk of modifying the input as we've already verified
         # there are no flattened fields.
-        if not isinstance(request, assuredworkloads_v1beta1.GetWorkloadRequest):
-            request = assuredworkloads_v1beta1.GetWorkloadRequest(request)
+        if not isinstance(request, assuredworkloads.GetWorkloadRequest):
+            request = assuredworkloads.GetWorkloadRequest(request)
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
             if name is not None:
@@ -801,21 +918,132 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.get_workload]
 
-        # Certain fields should be provided within the metadata header;
-        # add these here.
-        metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
+        # Done; return the response.
+        return response
+
+    def analyze_workload_move(
+        self,
+        request: Union[assuredworkloads.AnalyzeWorkloadMoveRequest, dict] = None,
+        *,
+        project: str = None,
+        target: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> assuredworkloads.AnalyzeWorkloadMoveResponse:
+        r"""Analyze if the source Assured Workloads can be moved
+        to the target Assured Workload
+
+        .. code-block:: python
+
+            from google.cloud import assuredworkloads_v1beta1
+
+            def sample_analyze_workload_move():
+                # Create a client
+                client = assuredworkloads_v1beta1.AssuredWorkloadsServiceClient()
+
+                # Initialize request argument(s)
+                request = assuredworkloads_v1beta1.AnalyzeWorkloadMoveRequest(
+                    source="source_value",
+                    target="target_value",
+                )
+
+                # Make the request
+                response = client.analyze_workload_move(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.assuredworkloads_v1beta1.types.AnalyzeWorkloadMoveRequest, dict]):
+                The request object. A request to analyze a hypothetical
+                move of a source project or project-based workload to a
+                target (destination) folder-based workload.
+            project (str):
+                The source type is a project. Specify the project's
+                relative resource name, formatted as either a project
+                number or a project ID: "projects/{PROJECT_NUMBER}" or
+                "projects/{PROJECT_ID}" For example:
+                "projects/951040570662" when specifying a project
+                number, or "projects/my-project-123" when specifying a
+                project ID.
+
+                This corresponds to the ``project`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            target (str):
+                Required. The resource ID of the folder-based
+                destination workload. This workload is where the source
+                project will hypothetically be moved to. Specify the
+                workload's relative resource name, formatted as:
+                "organizations/{ORGANIZATION_ID}/locations/{LOCATION_ID}/workloads/{WORKLOAD_ID}"
+                For example:
+                "organizations/123/locations/us-east1/workloads/assured-workload-2"
+
+                This corresponds to the ``target`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.assuredworkloads_v1beta1.types.AnalyzeWorkloadMoveResponse:
+                A response that includes the analysis
+                of the hypothetical resource move.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([project, target])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a assuredworkloads.AnalyzeWorkloadMoveRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, assuredworkloads.AnalyzeWorkloadMoveRequest):
+            request = assuredworkloads.AnalyzeWorkloadMoveRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if project is not None:
+                request.project = project
+            if target is not None:
+                request.target = target
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.analyze_workload_move]
+
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def list_workloads(
         self,
-        request: Union[assuredworkloads_v1beta1.ListWorkloadsRequest, dict] = None,
+        request: Union[assuredworkloads.ListWorkloadsRequest, dict] = None,
         *,
         parent: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
@@ -881,11 +1109,11 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
             )
 
         # Minor optimization to avoid making a copy if the user passes
-        # in a assuredworkloads_v1beta1.ListWorkloadsRequest.
+        # in a assuredworkloads.ListWorkloadsRequest.
         # There's no risk of modifying the input as we've already verified
         # there are no flattened fields.
-        if not isinstance(request, assuredworkloads_v1beta1.ListWorkloadsRequest):
-            request = assuredworkloads_v1beta1.ListWorkloadsRequest(request)
+        if not isinstance(request, assuredworkloads.ListWorkloadsRequest):
+            request = assuredworkloads.ListWorkloadsRequest(request)
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
             if parent is not None:
@@ -895,19 +1123,21 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         # and friendly error handling.
         rpc = self._transport._wrapped_methods[self._transport.list_workloads]
 
-        # Certain fields should be provided within the metadata header;
-        # add these here.
-        metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
-        )
-
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListWorkloadsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -926,6 +1156,114 @@ class AssuredWorkloadsServiceClient(metaclass=AssuredWorkloadsServiceClientMeta)
         """
         self.transport.close()
 
+    def list_operations(
+        self,
+        request: operations_pb2.ListOperationsRequest = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operations_pb2.ListOperationsResponse:
+        r"""Lists operations that match the specified filter in the request.
+
+        Args:
+            request (:class:`~.operations_pb2.ListOperationsRequest`):
+                The request object. Request message for
+                `ListOperations` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.operations_pb2.ListOperationsResponse:
+                Response message for ``ListOperations`` method.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.ListOperationsRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._transport.list_operations,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def get_operation(
+        self,
+        request: operations_pb2.GetOperationRequest = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operations_pb2.Operation:
+        r"""Gets the latest state of a long-running operation.
+
+        Args:
+            request (:class:`~.operations_pb2.GetOperationRequest`):
+                The request object. Request message for
+                `GetOperation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.operations_pb2.Operation:
+                An ``Operation`` object.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.GetOperationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._transport.get_operation,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
