@@ -26,7 +26,8 @@ from google.api_core import operations_v1
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads_v1beta1
+from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads
+from google.longrunning import operations_pb2
 from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 
@@ -57,6 +58,7 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -83,10 +85,6 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -108,6 +106,11 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -120,14 +123,28 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.create_workload: gapic_v1.method.wrap_method(
-                self.create_workload, default_timeout=60.0, client_info=client_info,
+                self.create_workload,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.update_workload: gapic_v1.method.wrap_method(
-                self.update_workload, default_timeout=60.0, client_info=client_info,
+                self.update_workload,
+                default_timeout=60.0,
+                client_info=client_info,
+            ),
+            self.restrict_allowed_resources: gapic_v1.method.wrap_method(
+                self.restrict_allowed_resources,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_workload: gapic_v1.method.wrap_method(
                 self.delete_workload,
@@ -157,6 +174,20 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
                 default_timeout=60.0,
                 client_info=client_info,
             ),
+            self.analyze_workload_move: gapic_v1.method.wrap_method(
+                self.analyze_workload_move,
+                default_retry=retries.Retry(
+                    initial=0.2,
+                    maximum=30.0,
+                    multiplier=1.3,
+                    predicate=retries.if_exception_type(
+                        core_exceptions.ServiceUnavailable,
+                    ),
+                    deadline=60.0,
+                ),
+                default_timeout=60.0,
+                client_info=client_info,
+            ),
             self.list_workloads: gapic_v1.method.wrap_method(
                 self.list_workloads,
                 default_retry=retries.Retry(
@@ -176,9 +207,9 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -191,7 +222,7 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
     def create_workload(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.CreateWorkloadRequest],
+        [assuredworkloads.CreateWorkloadRequest],
         Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
@@ -200,10 +231,19 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
     def update_workload(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.UpdateWorkloadRequest],
+        [assuredworkloads.UpdateWorkloadRequest],
+        Union[assuredworkloads.Workload, Awaitable[assuredworkloads.Workload]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def restrict_allowed_resources(
+        self,
+    ) -> Callable[
+        [assuredworkloads.RestrictAllowedResourcesRequest],
         Union[
-            assuredworkloads_v1beta1.Workload,
-            Awaitable[assuredworkloads_v1beta1.Workload],
+            assuredworkloads.RestrictAllowedResourcesResponse,
+            Awaitable[assuredworkloads.RestrictAllowedResourcesResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -212,7 +252,7 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
     def delete_workload(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.DeleteWorkloadRequest],
+        [assuredworkloads.DeleteWorkloadRequest],
         Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
@@ -221,10 +261,19 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
     def get_workload(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.GetWorkloadRequest],
+        [assuredworkloads.GetWorkloadRequest],
+        Union[assuredworkloads.Workload, Awaitable[assuredworkloads.Workload]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def analyze_workload_move(
+        self,
+    ) -> Callable[
+        [assuredworkloads.AnalyzeWorkloadMoveRequest],
         Union[
-            assuredworkloads_v1beta1.Workload,
-            Awaitable[assuredworkloads_v1beta1.Workload],
+            assuredworkloads.AnalyzeWorkloadMoveResponse,
+            Awaitable[assuredworkloads.AnalyzeWorkloadMoveResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -233,13 +282,38 @@ class AssuredWorkloadsServiceTransport(abc.ABC):
     def list_workloads(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.ListWorkloadsRequest],
+        [assuredworkloads.ListWorkloadsRequest],
         Union[
-            assuredworkloads_v1beta1.ListWorkloadsResponse,
-            Awaitable[assuredworkloads_v1beta1.ListWorkloadsResponse],
+            assuredworkloads.ListWorkloadsResponse,
+            Awaitable[assuredworkloads.ListWorkloadsResponse],
         ],
     ]:
         raise NotImplementedError()
 
+    @property
+    def list_operations(
+        self,
+    ) -> Callable[
+        [operations_pb2.ListOperationsRequest],
+        Union[
+            operations_pb2.ListOperationsResponse,
+            Awaitable[operations_pb2.ListOperationsResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_operation(
+        self,
+    ) -> Callable[
+        [operations_pb2.GetOperationRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("AssuredWorkloadsServiceTransport",)
