@@ -25,7 +25,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
-from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads_v1beta1
+from google.cloud.assuredworkloads_v1beta1.types import assuredworkloads
+from google.longrunning import operations_pb2
 from google.longrunning import operations_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 from .base import AssuredWorkloadsServiceTransport, DEFAULT_CLIENT_INFO
@@ -106,6 +107,7 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -202,6 +204,7 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -254,8 +257,7 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
     def create_workload(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.CreateWorkloadRequest],
-        Awaitable[operations_pb2.Operation],
+        [assuredworkloads.CreateWorkloadRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the create workload method over gRPC.
 
@@ -274,7 +276,7 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
         if "create_workload" not in self._stubs:
             self._stubs["create_workload"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/CreateWorkload",
-                request_serializer=assuredworkloads_v1beta1.CreateWorkloadRequest.serialize,
+                request_serializer=assuredworkloads.CreateWorkloadRequest.serialize,
                 response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_workload"]
@@ -283,8 +285,7 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
     def update_workload(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.UpdateWorkloadRequest],
-        Awaitable[assuredworkloads_v1beta1.Workload],
+        [assuredworkloads.UpdateWorkloadRequest], Awaitable[assuredworkloads.Workload]
     ]:
         r"""Return a callable for the update workload method over gRPC.
 
@@ -306,22 +307,59 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
         if "update_workload" not in self._stubs:
             self._stubs["update_workload"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/UpdateWorkload",
-                request_serializer=assuredworkloads_v1beta1.UpdateWorkloadRequest.serialize,
-                response_deserializer=assuredworkloads_v1beta1.Workload.deserialize,
+                request_serializer=assuredworkloads.UpdateWorkloadRequest.serialize,
+                response_deserializer=assuredworkloads.Workload.deserialize,
             )
         return self._stubs["update_workload"]
 
     @property
-    def delete_workload(
+    def restrict_allowed_resources(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.DeleteWorkloadRequest], Awaitable[empty_pb2.Empty]
+        [assuredworkloads.RestrictAllowedResourcesRequest],
+        Awaitable[assuredworkloads.RestrictAllowedResourcesResponse],
     ]:
+        r"""Return a callable for the restrict allowed resources method over gRPC.
+
+        Restrict the list of resources allowed in the
+        Workload environment. The current list of allowed
+        products can be found at
+        https://cloud.google.com/assured-workloads/docs/supported-products
+        In addition to assuredworkloads.workload.update
+        permission, the user should also have
+        orgpolicy.policy.set permission on the folder resource
+        to use this functionality.
+
+        Returns:
+            Callable[[~.RestrictAllowedResourcesRequest],
+                    Awaitable[~.RestrictAllowedResourcesResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "restrict_allowed_resources" not in self._stubs:
+            self._stubs["restrict_allowed_resources"] = self.grpc_channel.unary_unary(
+                "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/RestrictAllowedResources",
+                request_serializer=assuredworkloads.RestrictAllowedResourcesRequest.serialize,
+                response_deserializer=assuredworkloads.RestrictAllowedResourcesResponse.deserialize,
+            )
+        return self._stubs["restrict_allowed_resources"]
+
+    @property
+    def delete_workload(
+        self,
+    ) -> Callable[[assuredworkloads.DeleteWorkloadRequest], Awaitable[empty_pb2.Empty]]:
         r"""Return a callable for the delete workload method over gRPC.
 
         Deletes the workload. Make sure that workload's direct children
         are already in a deleted state, otherwise the request will fail
-        with a FAILED_PRECONDITION error.
+        with a FAILED_PRECONDITION error. In addition to
+        assuredworkloads.workload.delete permission, the user should
+        also have orgpolicy.policy.set permission on the deleted folder
+        to remove Assured Workloads OrgPolicies.
 
         Returns:
             Callable[[~.DeleteWorkloadRequest],
@@ -336,7 +374,7 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
         if "delete_workload" not in self._stubs:
             self._stubs["delete_workload"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/DeleteWorkload",
-                request_serializer=assuredworkloads_v1beta1.DeleteWorkloadRequest.serialize,
+                request_serializer=assuredworkloads.DeleteWorkloadRequest.serialize,
                 response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_workload"]
@@ -345,8 +383,7 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
     def get_workload(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.GetWorkloadRequest],
-        Awaitable[assuredworkloads_v1beta1.Workload],
+        [assuredworkloads.GetWorkloadRequest], Awaitable[assuredworkloads.Workload]
     ]:
         r"""Return a callable for the get workload method over gRPC.
 
@@ -365,17 +402,47 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
         if "get_workload" not in self._stubs:
             self._stubs["get_workload"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/GetWorkload",
-                request_serializer=assuredworkloads_v1beta1.GetWorkloadRequest.serialize,
-                response_deserializer=assuredworkloads_v1beta1.Workload.deserialize,
+                request_serializer=assuredworkloads.GetWorkloadRequest.serialize,
+                response_deserializer=assuredworkloads.Workload.deserialize,
             )
         return self._stubs["get_workload"]
 
+    @property
+    def analyze_workload_move(
+        self,
+    ) -> Callable[
+        [assuredworkloads.AnalyzeWorkloadMoveRequest],
+        Awaitable[assuredworkloads.AnalyzeWorkloadMoveResponse],
+    ]:
+        r"""Return a callable for the analyze workload move method over gRPC.
+
+        Analyze if the source Assured Workloads can be moved
+        to the target Assured Workload
+
+        Returns:
+            Callable[[~.AnalyzeWorkloadMoveRequest],
+                    Awaitable[~.AnalyzeWorkloadMoveResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "analyze_workload_move" not in self._stubs:
+            self._stubs["analyze_workload_move"] = self.grpc_channel.unary_unary(
+                "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/AnalyzeWorkloadMove",
+                request_serializer=assuredworkloads.AnalyzeWorkloadMoveRequest.serialize,
+                response_deserializer=assuredworkloads.AnalyzeWorkloadMoveResponse.deserialize,
+            )
+        return self._stubs["analyze_workload_move"]
+
     @property
     def list_workloads(
         self,
     ) -> Callable[
-        [assuredworkloads_v1beta1.ListWorkloadsRequest],
-        Awaitable[assuredworkloads_v1beta1.ListWorkloadsResponse],
+        [assuredworkloads.ListWorkloadsRequest],
+        Awaitable[assuredworkloads.ListWorkloadsResponse],
     ]:
         r"""Return a callable for the list workloads method over gRPC.
 
@@ -394,13 +461,49 @@ class AssuredWorkloadsServiceGrpcAsyncIOTransport(AssuredWorkloadsServiceTranspo
         if "list_workloads" not in self._stubs:
             self._stubs["list_workloads"] = self.grpc_channel.unary_unary(
                 "/google.cloud.assuredworkloads.v1beta1.AssuredWorkloadsService/ListWorkloads",
-                request_serializer=assuredworkloads_v1beta1.ListWorkloadsRequest.serialize,
-                response_deserializer=assuredworkloads_v1beta1.ListWorkloadsResponse.deserialize,
+                request_serializer=assuredworkloads.ListWorkloadsRequest.serialize,
+                response_deserializer=assuredworkloads.ListWorkloadsResponse.deserialize,
             )
         return self._stubs["list_workloads"]
 
     def close(self):
         return self.grpc_channel.close()
 
+    @property
+    def get_operation(
+        self,
+    ) -> Callable[[operations_pb2.GetOperationRequest], operations_pb2.Operation]:
+        r"""Return a callable for the get_operation method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_operation" not in self._stubs:
+            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+                "/google.longrunning.Operations/GetOperation",
+                request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["get_operation"]
+
+    @property
+    def list_operations(
+        self,
+    ) -> Callable[
+        [operations_pb2.ListOperationsRequest], operations_pb2.ListOperationsResponse
+    ]:
+        r"""Return a callable for the list_operations method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_operations" not in self._stubs:
+            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+                "/google.longrunning.Operations/ListOperations",
+                request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
+                response_deserializer=operations_pb2.ListOperationsResponse.FromString,
+            )
+        return self._stubs["list_operations"]
+
 
 __all__ = ("AssuredWorkloadsServiceGrpcAsyncIOTransport",)
