@@ -13,24 +13,32 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .assuredworkloads_v1beta1 import (
+from .assuredworkloads import (
+    AnalyzeWorkloadMoveRequest,
+    AnalyzeWorkloadMoveResponse,
     CreateWorkloadOperationMetadata,
     CreateWorkloadRequest,
     DeleteWorkloadRequest,
     GetWorkloadRequest,
     ListWorkloadsRequest,
     ListWorkloadsResponse,
+    RestrictAllowedResourcesRequest,
+    RestrictAllowedResourcesResponse,
     UpdateWorkloadRequest,
     Workload,
 )
 
 __all__ = (
+    "AnalyzeWorkloadMoveRequest",
+    "AnalyzeWorkloadMoveResponse",
     "CreateWorkloadOperationMetadata",
     "CreateWorkloadRequest",
     "DeleteWorkloadRequest",
     "GetWorkloadRequest",
     "ListWorkloadsRequest",
     "ListWorkloadsResponse",
+    "RestrictAllowedResourcesRequest",
+    "RestrictAllowedResourcesResponse",
     "UpdateWorkloadRequest",
     "Workload",
 )
